@@ -8,7 +8,7 @@ use Carp;
 require Exporter;
 use AutoLoader;
 
-our $VERSION = '1.10';
+our $VERSION = '1.12';
 
 
 #############################################################################
@@ -114,7 +114,7 @@ our $VERSION = '1.10';
 							cryptInit cryptEnd 
 							cryptQueryCapability 
 							cryptCreateContext cryptDestroyContext cryptDestroyObject 
-							cryptGenerateKey cryptGenerateKeyAsync cryptAsyncQuery cryptAsyncCancel 
+							cryptGenerateKey  
 							cryptEncrypt cryptDecrypt 
 							cryptSetAttribute cryptSetAttributeString cryptGetAttribute cryptGetAttributeString cryptDeleteAttribute 
 							cryptAddRandom 
@@ -130,7 +130,8 @@ our $VERSION = '1.10';
 							cryptDeviceOpen cryptDeviceClose cryptDeviceQueryCapability cryptDeviceCreateContext 
 							cryptLogin cryptLogout 
 						);
-
+	# Add deprecated functions when CRYPTLIB_VERSION prior 3.4.0
+	push @FUNCTIONS, qw(cryptGenerateKeyAsync cryptAsyncQuery cryptAsyncCancel) if &CRYPTLIB_VERSION < 340;
 
 	# Esportazione costanti e funzioni
 	our @ISA = qw(Exporter);
@@ -168,6 +169,8 @@ sub AUTOLOAD {
 
 require XSLoader;
 XSLoader::load('PerlCryptLib', $VERSION);
+## Add deprecated functions if CRYPTLIB_VERSION is less than 3.4.0
+#XSLoader::load('PerlCryptLib-deprecated-340', $VERSION) if &CRYPTLIB_VERSION < 340;
 
 if ( __FILE__ eq "$0" ) {
 	# TEST PACKAGE SPACE
